#include "myaudio.h"

MyAudio::MyAudio(QObject *parent,int freq) :
    QObject(parent),m_iFreq(freq)
{  
    GetAudioDev();
    SetFormat();
    SetAudioInput();
    SetAudioOutput();
}
//------------------------------------------------------------------

void MyAudio::GetAudioDev()
{
    m_DevlistOut = QAudioDeviceInfo::availableDevices(QAudio::AudioOutput);
    m_DevlistIn = QAudioDeviceInfo::availableDevices(QAudio::AudioInput);


    qDebug() << "Output devices:" << "\r\n";

    for(int i = 0; i < m_DevlistOut.length(); ++i)
    {
        qDebug() << m_DevlistOut.at(i).deviceName();
    }

    qDebug() << "\r\n";
    qDebug()  << "Input devices:" << "\r\n";

    for(int i = 0; i < m_DevlistIn.length(); ++i)
    {
        qDebug() << m_DevlistIn.at(i).deviceName();
    }

}

//------------------------------------------------------------------
void MyAudio::SetFormat()
{
    m_Aformat.setFrequency(m_iFreq);
    m_Aformat.setChannels(1);
    m_Aformat.setSampleSize(16);
    m_Aformat.setCodec("audio/pcm");
    m_Aformat.setByteOrder(QAudioFormat::LittleEndian);
    m_Aformat.setSampleType(QAudioFormat::SignedInt);


    qDebug() << "\r\nAudio format:\r\n";
    qDebug() << "Freq:        " <<  m_Aformat.frequency();
    qDebug() << "Channels:    " << m_Aformat.channels();
    qDebug() << "Sample size: " << m_Aformat.sampleSize();
    qDebug() << "Codec:       " << m_Aformat.codec();
    qDebug() << "Byte order:  " << m_Aformat.byteOrder();
    qDebug() << "Sample type: " << m_Aformat.sampleType();
    qDebug()<<"------------------------------------------";
    qDebug()<<"Prefer samplerate" << m_DevlistOut.at(0).preferredFormat().sampleRate();
}
//---------------------------------------------------------------------------------------
void MyAudio::SetAudioInput()
{
    QAudioDeviceInfo info = m_DevlistIn.at(0);

    if (!info.isFormatSupported(m_Aformat)) {

        qWarning()<<"default format not supported try to use nearest";
        m_Aformat = info.nearestFormat(m_Aformat);
        qDebug() << "Set new samplerate " << m_Aformat.frequency();
    }

    qDebug() << "\r\nUsed input device: " << info.deviceName();

    m_pAudioIn = new QAudioInput(info, m_Aformat);

    qDebug() << "\r\nStart record" ;

    m_pBufDev =  m_pAudioIn->start();

}
//---------------------------------------------------------------------------------------
void MyAudio::SetAudioOutput()
{
    QAudioDeviceInfo info = m_DevlistOut.at(0);

    if (!info.isFormatSupported(m_Aformat)) {

        qWarning()<<"default format not supported try to use nearest";
        m_Aformat = info.nearestFormat(m_Aformat);
        qDebug() << "Set new samplerate " << m_Aformat.frequency();
    }

    qDebug() << "\r\nUsed output device: " << info.deviceName();

    m_pAudioOut = new QAudioOutput(info, m_Aformat);

    connect(&m_OutTmr,SIGNAL(timeout()),this,SLOT(StartOutput()));

    m_OutTmr.setSingleShot(true);
    m_OutTmr.start(100);
}
//---------------------------------------------------------------------------------------

void MyAudio::StartOutput()
{
    m_pAudioOut->start(m_pBufDev);
}

//---------------------------------------------------------------------------------------

